@@ -51,34 +51,46 @@
 // We mean it.
 //
 
-#include <private/qtwebengineglobal_p.h>
-#include "qquickwebenginescript_p.h"
+#include <QtWebEngine/private/qtwebengineglobal_p.h>
 #include <QQuickItem>
 #include <QtGui/qcolor.h>
 
+#include "qquickwebenginescript.h"
+
 QT_BEGIN_NAMESPACE
 
 class QQmlWebChannel;
+class QQuickContextMenuBuilder;
+class QQuickWebEngineAction;
+class QQuickWebEngineAuthenticationDialogRequest;
 class QQuickWebEngineCertificateError;
-class QQuickWebEngineContextMenuData;
+class QQuickWebEngineClientCertificateSelection;
+class QQuickWebEngineColorDialogRequest;
+class QQuickWebEngineContextMenuRequest;
 class QQuickWebEngineFaviconProvider;
+class QQuickWebEngineFileDialogRequest;
 class QQuickWebEngineHistory;
+class QQuickWebEngineJavaScriptDialogRequest;
 class QQuickWebEngineLoadRequest;
 class QQuickWebEngineNavigationRequest;
 class QQuickWebEngineNewViewRequest;
 class QQuickWebEngineProfile;
 class QQuickWebEngineSettings;
-class QQuickWebEngineViewExperimental;
+class QQuickWebEngineTooltipRequest;
+class QQuickWebEngineFormValidationMessageRequest;
 class QQuickWebEngineViewPrivate;
+class QWebEngineFindTextResult;
+class QWebEngineQuotaRequest;
+class QWebEngineRegisterProtocolHandlerRequest;
 
-#ifdef ENABLE_QML_TESTSUPPORT_API
+#if QT_CONFIG(webengine_testsupport)
 class QQuickWebEngineTestSupport;
 #endif
 
 class Q_WEBENGINE_PRIVATE_EXPORT QQuickWebEngineFullScreenRequest {
     Q_GADGET
-    Q_PROPERTY(QUrl origin READ origin)
-    Q_PROPERTY(bool toggleOn READ toggleOn)
+    Q_PROPERTY(QUrl origin READ origin CONSTANT FINAL)
+    Q_PROPERTY(bool toggleOn READ toggleOn CONSTANT FINAL)
 public:
     QQuickWebEngineFullScreenRequest();
     QQuickWebEngineFullScreenRequest(QQuickWebEngineViewPrivate *viewPrivate, const QUrl &origin, bool toggleOn);
@@ -94,37 +106,41 @@ private:
     const bool m_toggleOn;
 };
 
-#define LATEST_WEBENGINEVIEW_REVISION 3
+#define LATEST_WEBENGINEVIEW_REVISION 10
 
 class Q_WEBENGINE_PRIVATE_EXPORT QQuickWebEngineView : public QQuickItem {
     Q_OBJECT
-    Q_PROPERTY(QUrl url READ url WRITE setUrl NOTIFY urlChanged)
-    Q_PROPERTY(QUrl icon READ icon NOTIFY iconChanged)
-    Q_PROPERTY(bool loading READ isLoading NOTIFY loadingChanged)
-    Q_PROPERTY(int loadProgress READ loadProgress NOTIFY loadProgressChanged)
-    Q_PROPERTY(QString title READ title NOTIFY titleChanged)
-    Q_PROPERTY(bool canGoBack READ canGoBack NOTIFY urlChanged)
-    Q_PROPERTY(bool canGoForward READ canGoForward NOTIFY urlChanged)
-    Q_PROPERTY(bool isFullScreen READ isFullScreen NOTIFY isFullScreenChanged REVISION 1)
-    Q_PROPERTY(qreal zoomFactor READ zoomFactor WRITE setZoomFactor NOTIFY zoomFactorChanged REVISION 1)
+    Q_CLASSINFO("RegisterEnumClassesUnscoped", "false")
+    Q_PROPERTY(QUrl url READ url WRITE setUrl NOTIFY urlChanged FINAL)
+    Q_PROPERTY(QUrl icon READ icon NOTIFY iconChanged FINAL)
+    Q_PROPERTY(bool loading READ isLoading NOTIFY loadingChanged FINAL)
+    Q_PROPERTY(int loadProgress READ loadProgress NOTIFY loadProgressChanged FINAL)
+    Q_PROPERTY(QString title READ title NOTIFY titleChanged FINAL)
+    Q_PROPERTY(bool canGoBack READ canGoBack NOTIFY urlChanged FINAL)
+    Q_PROPERTY(bool canGoForward READ canGoForward NOTIFY urlChanged FINAL)
+    Q_PROPERTY(bool isFullScreen READ isFullScreen NOTIFY isFullScreenChanged REVISION 1 FINAL)
+    Q_PROPERTY(qreal zoomFactor READ zoomFactor WRITE setZoomFactor NOTIFY zoomFactorChanged REVISION 1 FINAL)
     Q_PROPERTY(QQuickWebEngineProfile *profile READ profile WRITE setProfile NOTIFY profileChanged FINAL REVISION 1)
-    Q_PROPERTY(QQuickWebEngineSettings *settings READ settings REVISION 1)
+    Q_PROPERTY(QQuickWebEngineSettings *settings READ settings REVISION 1 CONSTANT FINAL)
     Q_PROPERTY(QQuickWebEngineHistory *navigationHistory READ navigationHistory CONSTANT FINAL REVISION 1)
-    Q_PROPERTY(QQmlWebChannel *webChannel READ webChannel WRITE setWebChannel NOTIFY webChannelChanged REVISION 1)
+    Q_PROPERTY(QQmlWebChannel *webChannel READ webChannel WRITE setWebChannel NOTIFY webChannelChanged REVISION 1 FINAL)
     Q_PROPERTY(QQmlListProperty<QQuickWebEngineScript> userScripts READ userScripts FINAL REVISION 1)
-    Q_PROPERTY(bool activeFocusOnPress READ activeFocusOnPress WRITE setActiveFocusOnPress NOTIFY activeFocusOnPressChanged REVISION 2)
-    Q_PROPERTY(QColor backgroundColor READ backgroundColor WRITE setBackgroundColor NOTIFY backgroundColorChanged REVISION 2)
+    Q_PROPERTY(bool activeFocusOnPress READ activeFocusOnPress WRITE setActiveFocusOnPress NOTIFY activeFocusOnPressChanged REVISION 2 FINAL)
+    Q_PROPERTY(QColor backgroundColor READ backgroundColor WRITE setBackgroundColor NOTIFY backgroundColorChanged REVISION 2 FINAL)
     Q_PROPERTY(QSizeF contentsSize READ contentsSize NOTIFY contentsSizeChanged FINAL REVISION 3)
     Q_PROPERTY(QPointF scrollPosition READ scrollPosition NOTIFY scrollPositionChanged FINAL REVISION 3)
     Q_PROPERTY(bool audioMuted READ isAudioMuted WRITE setAudioMuted NOTIFY audioMutedChanged FINAL REVISION 3)
     Q_PROPERTY(bool recentlyAudible READ recentlyAudible NOTIFY recentlyAudibleChanged FINAL REVISION 3)
-    Q_PROPERTY(uint webChannelWorld READ webChannelWorld WRITE setWebChannelWorld NOTIFY webChannelWorldChanged REVISION 3)
+    Q_PROPERTY(uint webChannelWorld READ webChannelWorld WRITE setWebChannelWorld NOTIFY webChannelWorldChanged REVISION 3 FINAL)
 
-#ifdef ENABLE_QML_TESTSUPPORT_API
-    Q_PROPERTY(QQuickWebEngineTestSupport *testSupport READ testSupport WRITE setTestSupport FINAL)
+    Q_PROPERTY(QQuickWebEngineView *inspectedView READ inspectedView WRITE setInspectedView NOTIFY inspectedViewChanged REVISION 7 FINAL)
+    Q_PROPERTY(QQuickWebEngineView *devToolsView READ devToolsView WRITE setDevToolsView NOTIFY devToolsViewChanged REVISION 7 FINAL)
+#if QT_CONFIG(webengine_testsupport)
+    Q_PROPERTY(QQuickWebEngineTestSupport *testSupport READ testSupport WRITE setTestSupport NOTIFY testSupportChanged FINAL)
 #endif
 
-    Q_FLAGS(FindFlags);
+    Q_PROPERTY(LifecycleState lifecycleState READ lifecycleState WRITE setLifecycleState NOTIFY lifecycleStateChanged REVISION 10 FINAL)
+    Q_PROPERTY(LifecycleState recommendedState READ recommendedState NOTIFY recommendedStateChanged REVISION 10 FINAL)
 
 public:
     QQuickWebEngineView(QQuickItem *parent = 0);
@@ -146,13 +162,11 @@ public:
     QSizeF contentsSize() const;
     QPointF scrollPosition() const;
 
-    QQuickWebEngineViewExperimental *experimental() const;
-
     // must match WebContentsAdapterClient::NavigationRequestAction
     enum NavigationRequestAction {
         AcceptRequest,
         // Make room in the valid range of the enum so
-        // we can expose extra actions in experimental.
+        // we can expose extra actions.
         IgnoreRequest = 0xFF
     };
     Q_ENUM(NavigationRequestAction)
@@ -164,7 +178,8 @@ public:
         FormSubmittedNavigation,
         BackForwardNavigation,
         ReloadNavigation,
-        OtherNavigation
+        OtherNavigation,
+        RedirectNavigation,
     };
     Q_ENUM(NavigationType)
 
@@ -199,7 +214,10 @@ public:
         MediaAudioCapture,
         MediaVideoCapture,
         MediaAudioVideoCapture,
-        Geolocation
+        Geolocation,
+        DesktopVideoCapture,
+        DesktopAudioVideoCapture,
+        Notifications,
     };
     Q_ENUM(Feature)
 
@@ -243,6 +261,23 @@ public:
         RequestClose,
         Unselect,
         SavePage,
+        ViewSource,
+
+        ToggleBold,
+        ToggleItalic,
+        ToggleUnderline,
+        ToggleStrikethrough,
+
+        AlignLeft,
+        AlignCenter,
+        AlignRight,
+        AlignJustified,
+        Indent,
+        Outdent,
+
+        InsertOrderedList,
+        InsertUnorderedList,
+
         WebActionCount
     };
     Q_ENUM(WebAction)
@@ -269,6 +304,7 @@ public:
         FindCaseSensitively = 2,
     };
     Q_DECLARE_FLAGS(FindFlags, FindFlag)
+    Q_FLAG(FindFlags)
 
     // must match QPageSize::PageSizeId
     enum PrintedPageSizeId {
@@ -430,31 +466,50 @@ public:
     };
     Q_ENUM(PrintedPageOrientation)
 
-    // QmlParserStatus
-    virtual void componentComplete() Q_DECL_OVERRIDE;
+    // must match WebContentsAdapterClient::LifecycleState
+    enum class LifecycleState {
+        Active,
+        Frozen,
+        Discarded,
+    };
+    Q_ENUM(LifecycleState)
 
-    QQuickWebEngineProfile *profile() const;
+    // QmlParserStatus
+    void componentComplete() override;
+
+    QQuickWebEngineProfile *profile();
     void setProfile(QQuickWebEngineProfile *);
     QQmlListProperty<QQuickWebEngineScript> userScripts();
 
-    QQuickWebEngineSettings *settings() const;
+    QQuickWebEngineSettings *settings();
     QQmlWebChannel *webChannel();
     void setWebChannel(QQmlWebChannel *);
     QQuickWebEngineHistory *navigationHistory() const;
     uint webChannelWorld() const;
     void setWebChannelWorld(uint);
+    Q_REVISION(8) Q_INVOKABLE QQuickWebEngineAction *action(WebAction action);
 
     bool isAudioMuted() const;
     void setAudioMuted(bool muted);
     bool recentlyAudible() const;
 
-#ifdef ENABLE_QML_TESTSUPPORT_API
+#if QT_CONFIG(webengine_testsupport)
     QQuickWebEngineTestSupport *testSupport() const;
     void setTestSupport(QQuickWebEngineTestSupport *testSupport);
 #endif
 
     bool activeFocusOnPress() const;
 
+    void setInspectedView(QQuickWebEngineView *);
+    QQuickWebEngineView *inspectedView() const;
+    void setDevToolsView(QQuickWebEngineView *);
+    QQuickWebEngineView *devToolsView() const;
+
+    LifecycleState lifecycleState() const;
+    void setLifecycleState(LifecycleState state);
+
+    LifecycleState recommendedState() const;
+
 public Q_SLOTS:
     void runJavaScript(const QString&, const QJSValue & = QJSValue());
     Q_REVISION(3) void runJavaScript(const QString&, quint32 worldId, const QJSValue & = QJSValue());
@@ -472,6 +527,8 @@ public Q_SLOTS:
     Q_REVISION(2) void triggerWebAction(WebAction action);
     Q_REVISION(3) void printToPdf(const QString &filePath, PrintedPageSizeId pageSizeId = PrintedPageSizeId::A4, PrintedPageOrientation orientation = PrintedPageOrientation::Portrait);
     Q_REVISION(3) void printToPdf(const QJSValue &callback, PrintedPageSizeId pageSizeId = PrintedPageSizeId::A4, PrintedPageOrientation orientation = PrintedPageOrientation::Portrait);
+    Q_REVISION(4) void replaceMisspelledWord(const QString &replacement);
+
 private Q_SLOTS:
     void lazyInitialize();
 
@@ -501,21 +558,44 @@ Q_SIGNALS:
     Q_REVISION(3) void audioMutedChanged(bool muted);
     Q_REVISION(3) void recentlyAudibleChanged(bool recentlyAudible);
     Q_REVISION(3) void webChannelWorldChanged(uint);
+    Q_REVISION(4) void contextMenuRequested(QQuickWebEngineContextMenuRequest *request);
+    Q_REVISION(4) void authenticationDialogRequested(QQuickWebEngineAuthenticationDialogRequest *request);
+    Q_REVISION(4) void javaScriptDialogRequested(QQuickWebEngineJavaScriptDialogRequest *request);
+    Q_REVISION(4) void colorDialogRequested(QQuickWebEngineColorDialogRequest *request);
+    Q_REVISION(4) void fileDialogRequested(QQuickWebEngineFileDialogRequest *request);
+    Q_REVISION(4) void formValidationMessageRequested(QQuickWebEngineFormValidationMessageRequest *request);
+    Q_REVISION(5) void pdfPrintingFinished(const QString &filePath, bool success);
+    Q_REVISION(7) void quotaRequested(const QWebEngineQuotaRequest &request);
+    Q_REVISION(7) void geometryChangeRequested(const QRect &geometry, const QRect &frameGeometry);
+    Q_REVISION(7) void inspectedViewChanged();
+    Q_REVISION(7) void devToolsViewChanged();
+    Q_REVISION(7) void registerProtocolHandlerRequested(const QWebEngineRegisterProtocolHandlerRequest &request);
+    Q_REVISION(8) void printRequested();
+    Q_REVISION(9) void selectClientCertificate(QQuickWebEngineClientCertificateSelection *clientCertSelection);
+    Q_REVISION(10) void tooltipRequested(QQuickWebEngineTooltipRequest *request);
+    Q_REVISION(10) void lifecycleStateChanged(LifecycleState state);
+    Q_REVISION(10) void recommendedStateChanged(LifecycleState state);
+    Q_REVISION(10) void findTextFinished(const QWebEngineFindTextResult &result);
+
+#if QT_CONFIG(webengine_testsupport)
+    void testSupportChanged();
+#endif
 
 protected:
-    void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry);
-    void itemChange(ItemChange, const ItemChangeData &);
-    void dragEnterEvent(QDragEnterEvent *e) Q_DECL_OVERRIDE;
-    void dragLeaveEvent(QDragLeaveEvent *e) Q_DECL_OVERRIDE;
-    void dragMoveEvent(QDragMoveEvent *e) Q_DECL_OVERRIDE;
-    void dropEvent(QDropEvent *e) Q_DECL_OVERRIDE;
+    void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+    void itemChange(ItemChange, const ItemChangeData &) override;
+#if QT_CONFIG(draganddrop)
+    void dragEnterEvent(QDragEnterEvent *e) override;
+    void dragLeaveEvent(QDragLeaveEvent *e) override;
+    void dragMoveEvent(QDragMoveEvent *e) override;
+    void dropEvent(QDropEvent *e) override;
+#endif // QT_CONFIG(draganddrop)
 
 private:
     Q_DECLARE_PRIVATE(QQuickWebEngineView)
     QScopedPointer<QQuickWebEngineViewPrivate> d_ptr;
 
-    friend class QQuickWebEngineViewExperimental;
-    friend class QQuickWebEngineViewExperimentalExtension;
+    friend class QQuickContextMenuBuilder;
     friend class QQuickWebEngineNewViewRequest;
     friend class QQuickWebEngineFaviconProvider;
 #ifndef QT_NO_ACCESSIBILITY
